[Zope3-checkins] CVS: Zope3 - ft.py:1.2 test.py:1.95

Jim Fulton jim at zope.com
Tue Apr 6 16:58:29 EDT 2004


Update of /cvs-repository/Zope3
In directory cvs.zope.org:/tmp/cvs-serv5422

Modified Files:
	ft.py test.py 
Log Message:
Moved the functional tests to zope.app, since they depend on zope.app.


=== Zope3/ft.py 1.1 => 1.2 ===
--- Zope3/test.py:1.94	Wed Mar 17 17:04:07 2004
+++ Zope3/test.py	Tue Apr  6 16:57:58 2004
@@ -436,7 +436,7 @@
                 # parent directory
                 config_file = os.path.join('..', 'ftesting.zcml')
             print "Parsing %s" % config_file
-            from zope.testing.functional import FunctionalTestSetup
+            from zope.app.tests.functional import FunctionalTestSetup
             FunctionalTestSetup(config_file)
 
 def match(rx, s):




More information about the Zope3-Checkins mailing list
--- Zope3/ft.py:1.1	Tue Jun 24 07:23:18 2003
+++ Zope3/ft.py	Tue Apr  6 16:57:58 2004
@@ -19,7 +19,7 @@
 """
 
 import unittest
-from zope.testing.functional import FunctionalTestCase
+from zope.app.tests.functional import FunctionalTestCase
 
 # If you are writing a functional test that simulates browser requests, use
 # BrowserTestCase instead of FunctionalTestCase
@@ -60,7 +60,7 @@
         #
         # There are helper methods in FunctionalTestCase and BrowserTestCase
         # for accessing the ZODB and emulating publication requests.  See the
         # docstrings in zope.testing.functional module.
         pass
 
 
@@ -60,7 +60,7 @@
         # There are helper methods in FunctionalTestCase and BrowserTestCase
         # for accessing the ZODB and emulating publication requests.  See the
-        # docstrings in zope.testing.functional module.
+        # docstrings in zope.app.tests.functional module.
         pass
 


=== Zope3/test.py 1.94 => 1.95 ===